//TODO this needs rework: 
//rugraph::Graph and rugraph::MultiDiGraph
pub mod rugraph;
pub mod graph;
pub mod digraph;
pub mod multidigraph;